summaryrefslogtreecommitdiff
path: root/include/dm/platform_data/spi_coldfire.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/dm/platform_data/spi_coldfire.h')
-rw-r--r--include/dm/platform_data/spi_coldfire.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/dm/platform_data/spi_coldfire.h b/include/dm/platform_data/spi_coldfire.h
index 8ad8eaedfd..da514bad0d 100644
--- a/include/dm/platform_data/spi_coldfire.h
+++ b/include/dm/platform_data/spi_coldfire.h
@@ -10,14 +10,14 @@
#define MAX_CTAR_FIELDS 8
/*
* struct coldfire_spi_platdata - information about a coldfire spi module
*
* @regs_addr: base address for module registers
* @speed_hz: default SCK frequency
* @mode: default SPI mode
* @num_cs: number of DSPI chipselect signals
*/
-struct coldfire_spi_platdata {
+struct coldfire_spi_plat {
fdt_addr_t regs_addr;
uint speed_hz;
uint mode;
@@ -10,14 +10,14 @@
#define MAX_CTAR_FIELDS 8
/*
- * struct coldfire_spi_platdata - information about a coldfire spi module
+ * struct coldfire_spi_plat - information about a coldfire spi module
*
* @regs_addr: base address for module registers